============
Introduction
============

**Swiss Ephemeris** is a function package of astronomical calculations that
serves the needs of astrologers, archeoastronomers, and, depending on purpose,
also the needs of astronomers. It includes long-term ephemerides for the Sun,
the Moon, the planets, more than 300.000 asteroids, historically relevant fixed
stars and some "hypothetical" objects.

The precision of the Swiss Ephemeris is at least as good as that of the
Astronomical Almanac, which follows current standards of ephemeris calculation.
Swiss Ephemeris will, as we hope, be able to keep abreast to the scientific
advances in ephemeris computation for the coming decades.

Licensing
=========

The Swiss Ephemeris is not a product for end users. It is a toolset for
programmers to build into their astrological software.

Swiss Ephemeris is made available by its authors under a dual licensing system.
The software developer, who uses any part of Swiss Ephemeris in his or her
software, must choose between one of the two license models, which are:

 - GNU Affero General Public License version 3
 - Swiss Ephemeris Professional License

The choice must be made before the software developer distributes software
containing parts of Swiss Ephemeris to others, and before any public service
using the developed software is activated.

If the developer choses the GNU AGPL software license, he or she must fulfill
the conditions of that license, which includes the obligation to place his or
her whole software project under the GNU AGPL or a compatible license.
See https://www.gnu.org/licenses/agpl-3.0.en.html

If the developer choses the Swiss Ephemeris Professional license, he must
follow the instructions as found in http://www.astro.com/swisseph/ and purchase
the Swiss Ephemeris Professional Edition from Astrodienst and sign the
corresponding license contract.

The Swiss Ephemeris Professional Edition can be purchased from Astrodienst for
a one-time fixed fee for each commercial programming project. The license is
just a legal document. All actual software and data are found in the public
download area and are to be downloaded from there.

Professional license: The license fee for the first license is Swiss Francs
(CHF) 750.-, and CHF 400.- for each additional license by the same licensee.
An unlimited license is available for CHF 1550.-.

Status of this documentation
============================

This documentation is tailored to users of the Python extension to the Swiss
Ephemeris library (Pyswisseph).
Most of its content is taken from the original documentation that you can find
on the `Swiss Ephemeris website`_.

Pyswisseph is not related to the company AstroDienst or astro.com website.

.. _Swiss Ephemeris website: https://www.astro.com/swisseph

..
